@@ -14,8 +14,7 @@ TPXO_FILENAME = 'h_tpxo9.v1.nc'
 
 
 class TPXO(TidalDataset):
-    CONSTITUENTS = ['M2', 'S2', 'N2', 'K2', 'K1', 'O1', 'P1', 'Q1', 'Mm', 'Mf',
-                    'M4', 'MN4', 'MS4', '2N2', 'S1']
+
     DEFAULT_PATH = Path(appdirs.user_data_dir('tpxo')) / TPXO_FILENAME
 
     def __init__(self, tpxo_dataset_filename: PathLike = None):
@@ -77,6 +76,14 @@ class TPXO(TidalDataset):
     def hp(self) -> np.ndarray:
         return self.dataset['hp'][:]
 
+    @property
+    def constituents(self):
+        if not hasattr(self, '_constituents'):
+            self._constituents = [
+                c.capitalize() for c in self.dataset['con'][:].astype(
+                    '|S1').tostring().decode('utf-8').split()]
+        return self._constituents
+
     def _get_interpolation(self, tpxo_array: np.ndarray, constituent: str,
                            vertices: np.ndarray):
         """
@@ -85,8 +92,8 @@ class TPXO(TidalDataset):
         """
 
         self._assert_vertices(vertices)
-
-        constituent = self.CONSTITUENTS.index(constituent)
+        constituents = list(map(lambda x: x.lower(), self.constituents))
+        constituent = constituents.index(constituent.lower())
         array = tpxo_array[constituent, :, :].flatten()
         _x = np.asarray([x + 360. for x in vertices[:, 0] if x < 0]).flatten()
         _y = vertices[:, 1].flatten()
