@@ -6,7 +6,6 @@ import pathlib
 import numpy as np
 
 from adcircpy.mesh.mesh import AdcircMesh
-from adcircpy.forcing.tides import Tides
 
 
 class Fort15:
@@ -342,8 +341,8 @@ class Fort15:
                     f.append(f'{constituent}')
                     vertices = self.mesh.get_xy(crs='EPSG:4326')[
                                bnd['indexes'], :]
-                    amp, phase = self.tidal_forcing.tidal_database(
-                        constituent, vertices)
+                    amp, phase = self.tidal_forcing.tidal_dataset(
+                            constituent, vertices)
                     f.extend(f'{amp[i]:.8e} {phase[i]:.8e}' for i in
                              range(len(vertices)))
             elif bnd['iettype'] in 2:
@@ -525,7 +524,7 @@ class Fort15:
     @property
     def gwce_solution_scheme(self):
         """
-        'semi-implicit' (default) | 'explicit'
+        'semi-implicit' (default) | 'explicit | 'semi-implicit-legacy'
         """
         try:
             return self.__gwce_solution_scheme
@@ -1123,7 +1122,7 @@ class Fort15:
             return self.__B00
         except AttributeError:
             if self.gwce_solution_scheme == 'explicit':
-                return 0
+                return 1
             if self.gwce_solution_scheme == 'semi-implicit-legacy':
                 return 0.30
             if self.gwce_solution_scheme == 'semi-implicit':
@@ -2193,7 +2192,8 @@ class Fort15:
 
     @gwce_solution_scheme.setter
     def gwce_solution_scheme(self, gwce_solution_scheme):
-        assert gwce_solution_scheme in ['semi-implicit', 'explicit']
+        assert gwce_solution_scheme in ['semi-implicit', 'explicit',
+                                        'semi-implicit-legacy']
         self.__gwce_solution_scheme = gwce_solution_scheme
 
     @passive_scalar_transport.setter
